@@ -10,12 +10,8 @@ from .base_request import BaseRequest
 class Actions(BaseRequest):
     """Assertio Request object."""
 
-    def __init__(
-        self,
-        method: Optional[str] = None,
-        endpoint: Optional[str] = None
-    ):
-        super().__init__(method, endpoint)
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
 
     @when
     def perform(self):
