@@ -4,14 +4,10 @@ from typing import Dict, Optional, Union
 class BaseRequest:
     """Assertio Request object."""
 
-    def __init__(
-        self,
-        method: Optional[str] = None,
-        endpoint: Optional[str] = None
-    ):
+    def __init__(self, method: Optional[str] = None):
         """Class constructor."""
         self._body: Union[Dict, None] = None
-        self._endpoint: Union[str, None] = endpoint
+        self._endpoint: Union[str, None] = None
         self._headers: Union[Dict, None] = None
         self._method: Union[str, None] = method
         self._params: Union[Dict, None] = None
